@@ -88,8 +88,8 @@ void GenerateOpenvpnKeyDialog::canAccept()
 	generateOpenvpnKeyProcess->addArgument("--secret");
 	generateOpenvpnKeyProcess->addArgument(filename);
 
-	connect( generateOpenvpnKeyProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErr() ) );
-	connect( generateOpenvpnKeyProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdErr() ) );
+	connect( generateOpenvpnKeyProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErr() ) );
+	connect( generateOpenvpnKeyProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdErr() ) );
 	if ( !generateOpenvpnKeyProcess->start(env) )
 	{
 		KMessageBox::sorry( this, i18n( "Generating of %1 key failed!" ).arg( "openvpn" ) );
@@ -105,8 +105,8 @@ void GenerateOpenvpnKeyDialog::canAccept()
 	{
 		sleep(1);
 	}
-	disconnect( generateOpenvpnKeyProcess, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readStdErr() ) );
-	disconnect( generateOpenvpnKeyProcess, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readStdErr() ) );
+	disconnect( generateOpenvpnKeyProcess, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readStdErr() ) );
+	disconnect( generateOpenvpnKeyProcess, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readStdErr() ) );
 	delete generateOpenvpnKeyProcess;
 	generateOpenvpnKeyProcess = 0L;
 	if (genOk)
