@@ -562,12 +562,12 @@ void ImportIpsecProfileDialog::canAccept()
 					{
 						validLineFound=true;
 						TQString LeftNextHop=line2.section ( "leftnexthop=",1,-1 );
-						std::cout << "left next hop (local) found: " << LeftNextHop << std::endl;
+						std::cout << "left next hop (local) found: " << LeftNextHop.local8Bit() << std::endl;
 						if (GlobalConfig->KvpncDebugLevel > 2)
 							GlobalConfig->appendLogEntry("import ipsec config: left next hop (local) found: " +LeftNextHop ,GlobalConfig->debug);
 						profiledata->setLeftNextHop(LeftNextHop);
 						profiledata->setUseLeftNextHop(true);
-						std::cout << "	=> set it for profile " << IpsecConfigSection << " ." << std::endl;
+						std::cout << "	=> set it for profile " << IpsecConfigSection.local8Bit() << " ." << std::endl;
 						if (GlobalConfig->KvpncDebugLevel > 2)
 							GlobalConfig->appendLogEntry("import ipsec config: => set it for profile " + IpsecConfigSection + " ." ,GlobalConfig->debug);
 					}
@@ -763,7 +763,7 @@ void ImportIpsecProfileDialog::canAccept()
 					{
 						validLineFound=true;
 						TQString leftsourceip=line2.section ( "leftsourceip=",1,-1 );
-							std::cout << "left (local) have to use IP address " << leftsourceip << std::endl;
+							std::cout << "left (local) have to use IP address " << leftsourceip.local8Bit() << std::endl;
 						if (GlobalConfig->KvpncDebugLevel > 2)
 							GlobalConfig->appendLogEntry("import ipsec config: left (local) have to use IP address " + leftsourceip ,GlobalConfig->debug);
 						profiledata->setLocalVirtualIP(leftsourceip);
@@ -775,7 +775,7 @@ void ImportIpsecProfileDialog::canAccept()
 					{
 						validLineFound=true;
 						TQString virtualprivate=line2.section ( "virtual_private=",1,-1 );
-											std::cout << "virtual private networks " << virtualprivate << std::endl;
+											std::cout << "virtual private networks " << virtualprivate.local8Bit() << std::endl;
 						if (GlobalConfig->KvpncDebugLevel > 2)
 							GlobalConfig->appendLogEntry("import ipsec config: virtual private networks " +virtualprivate ,GlobalConfig->debug);
 						profiledata->setLocalVirtualIP(virtualprivate);
@@ -788,7 +788,7 @@ void ImportIpsecProfileDialog::canAccept()
 					{
 						validLineFound=true;
 						TQString rightsourceip=line2.section ( "rightsourceip=",1,-1 );
-											std::cout << "right (remote) have to use IP address " << rightsourceip << std::endl;
+											std::cout << "right (remote) have to use IP address " << rightsourceip.local8Bit() << std::endl;
 						if (GlobalConfig->KvpncDebugLevel > 2)
 							GlobalConfig->appendLogEntry("import ipsec config: right (remote) have to use IP address " + rightsourceip ,GlobalConfig->debug);
 						profiledata->setRightSourceIp(rightsourceip);
