@@ -154,9 +154,9 @@ TQString NetworkInterface::getInterfaceIP2( TQString Interface )
                 retrieveInterfaceIP=true;
                 readOutput=true;
 
-                connect( InterfaceIpProc, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readFromStdout_interfaceip() ) );
-                connect( InterfaceIpProc, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readFromStderr_interfaceip() ) );
-                connect( InterfaceIpProc, TQT_SIGNAL( processExited () ), this, TQT_SLOT( processHasFinished() ) );
+                connect( InterfaceIpProc, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readFromStdout_interfaceip() ) );
+                connect( InterfaceIpProc, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readFromStderr_interfaceip() ) );
+                connect( InterfaceIpProc, TQ_SIGNAL( processExited () ), this, TQ_SLOT( processHasFinished() ) );
 
                 if ( !InterfaceIpProc->start(env) )
                 {
@@ -174,9 +174,9 @@ TQString NetworkInterface::getInterfaceIP2( TQString Interface )
                         while ( readOutput)
                                 GlobalConfig->appPointer->processEvents();*/
                 }
-		disconnect( InterfaceIpProc, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readFromStdout_interfaceip() ) );
-		disconnect( InterfaceIpProc, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readFromStderr_interfaceip() ) );
-		disconnect( InterfaceIpProc, TQT_SIGNAL( processExited () ), this, TQT_SLOT( processHasFinished() ) );
+		disconnect( InterfaceIpProc, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readFromStdout_interfaceip() ) );
+		disconnect( InterfaceIpProc, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readFromStderr_interfaceip() ) );
+		disconnect( InterfaceIpProc, TQ_SIGNAL( processExited () ), this, TQ_SLOT( processHasFinished() ) );
 		delete InterfaceIpProc;
 		InterfaceIpProc=0L;
         }
@@ -213,9 +213,9 @@ TQString NetworkInterface::getInterfaceAddress( TQString IPforInterface )
 			retrieveInterfaceAddress=true;
 			readOutput=true;
 
-			//connect( InterfaceAddressProc, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readFromStdout_interfaceaddress() ) );
-			//	connect( InterfaceAddressProc, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readFromStderr_interfaceaddress() ) );
-			connect( InterfaceAddressProc, TQT_SIGNAL( processExited () ), this, TQT_SLOT( processHasFinished() ) );
+			//connect( InterfaceAddressProc, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readFromStdout_interfaceaddress() ) );
+			//	connect( InterfaceAddressProc, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readFromStderr_interfaceaddress() ) );
+			connect( InterfaceAddressProc, TQ_SIGNAL( processExited () ), this, TQ_SLOT( processHasFinished() ) );
 
 
 			if ( !InterfaceAddressProc->start(env) )
@@ -237,9 +237,9 @@ TQString NetworkInterface::getInterfaceAddress( TQString IPforInterface )
 // 					GlobalConfig->appPointer->processEvents();
 				}
 
-				// 		disconnect( InterfaceAddressProc, TQT_SIGNAL( readyReadStdout() ), this, TQT_SLOT( readFromStdout_interfaceaddress() ) );
-				// 		disconnect( InterfaceAddressProc, TQT_SIGNAL( readyReadStderr() ), this, TQT_SLOT( readFromStderr_interfaceaddress() ) );
-				disconnect( InterfaceAddressProc, TQT_SIGNAL( processExited () ), this, TQT_SLOT( processHasFinished() ) );
+				// 		disconnect( InterfaceAddressProc, TQ_SIGNAL( readyReadStdout() ), this, TQ_SLOT( readFromStdout_interfaceaddress() ) );
+				// 		disconnect( InterfaceAddressProc, TQ_SIGNAL( readyReadStderr() ), this, TQ_SLOT( readFromStderr_interfaceaddress() ) );
+				disconnect( InterfaceAddressProc, TQ_SIGNAL( processExited () ), this, TQ_SLOT( processHasFinished() ) );
 				//delete InterfaceAddressProc;
 			}
 		}
@@ -409,7 +409,7 @@ TQString  NetworkInterface::getExternalIpAddress()
 	ExternalIpAddress="";
 	getExternalIpAddressRunning=true;
 	http = new TQHttp();
-	connect (http,TQT_SIGNAL(readyRead(const TQHttpResponseHeader &)), this, TQT_SLOT(externalIpDataRecieved(const TQHttpResponseHeader &)));
+	connect (http,TQ_SIGNAL(readyRead(const TQHttpResponseHeader &)), this, TQ_SLOT(externalIpDataRecieved(const TQHttpResponseHeader &)));
 
 	// FIXME how it could be better?
 	http->setHost( "checkip.dyndns.org" );
