@@ -53,14 +53,14 @@ NewProfileDialog::NewProfileDialog( TQApplication *app,TQWidget *parent, const T
 	setMainWidget(main);
 	main->setMinimumSize(main->sizeHint());
 
-	connect( main->ConnectionTypeComboBox, TQT_SIGNAL( activated( const TQString& ) ), this, TQT_SLOT( connectiontypeChanged( const TQString& ) ) );
-	connect( main->AuthTypeComboBox , TQT_SIGNAL( activated( const TQString& ) ), this, TQT_SLOT( authTypeChanged( const TQString& ) ) );
-	//	connect( main->buttonCancel , TQT_SIGNAL( clicked () ), this, TQT_SLOT( reject() ) );
-	connect( main->ImportCertificatePushButton, TQT_SIGNAL( clicked () ), this, TQT_SLOT( importCertificate() ) );
-	connect( main->AdvancedSettingsPushButton, TQT_SIGNAL( clicked () ), this, TQT_SLOT( advancedSettingsClicked() ) );
-	connect( main->ImportPcfProfilePushButton , TQT_SIGNAL( clicked () ), this, TQT_SLOT( importPcfFileClicked() ) );
-	connect( main->GroupPasswordEdit, TQT_SIGNAL( textChanged(const TQString&) ), this, TQT_SLOT( groupPasswordContentChanged() ) );
-	connect( main->PasswordEdit, TQT_SIGNAL( textChanged(const TQString&) ), this, TQT_SLOT( passwordContentChanged() ) );
+	connect( main->ConnectionTypeComboBox, TQ_SIGNAL( activated( const TQString& ) ), this, TQ_SLOT( connectiontypeChanged( const TQString& ) ) );
+	connect( main->AuthTypeComboBox , TQ_SIGNAL( activated( const TQString& ) ), this, TQ_SLOT( authTypeChanged( const TQString& ) ) );
+	//	connect( main->buttonCancel , TQ_SIGNAL( clicked () ), this, TQ_SLOT( reject() ) );
+	connect( main->ImportCertificatePushButton, TQ_SIGNAL( clicked () ), this, TQ_SLOT( importCertificate() ) );
+	connect( main->AdvancedSettingsPushButton, TQ_SIGNAL( clicked () ), this, TQ_SLOT( advancedSettingsClicked() ) );
+	connect( main->ImportPcfProfilePushButton , TQ_SIGNAL( clicked () ), this, TQ_SLOT( importPcfFileClicked() ) );
+	connect( main->GroupPasswordEdit, TQ_SIGNAL( textChanged(const TQString&) ), this, TQ_SLOT( groupPasswordContentChanged() ) );
+	connect( main->PasswordEdit, TQ_SIGNAL( textChanged(const TQString&) ), this, TQ_SLOT( passwordContentChanged() ) );
 	newProfileCreated = FALSE;
 	Name = "";
 
@@ -667,3 +667,4 @@ void NewProfileDialog::passwordContentChanged()
 		main->CheckUserPass->setChecked(false);
 }
 
+#include "newprofiledialog.moc"
