@@ -54,18 +54,18 @@ void OpenvpnManagementHandler::closeConnection()
 {
 	if (socket)
 	{
-		//disconnect( socket, TQT_SIGNAL( connected() ), this, TQT_SLOT( socketConnected() ) );
-		disconnect( socket, TQT_SIGNAL( connectionClosed() ), this, TQT_SLOT( socketConnectionClosed() ) );
-		disconnect( socket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( socketReadyRead() ) );
-		disconnect( socket, TQT_SIGNAL( error( int ) ), this, TQT_SLOT( socketError( int ) ) );
-		disconnect( socket, TQT_SIGNAL( hostFound() ), this, TQT_SLOT( hostFound() ) );
+		//disconnect( socket, TQ_SIGNAL( connected() ), this, TQ_SLOT( socketConnected() ) );
+		disconnect( socket, TQ_SIGNAL( connectionClosed() ), this, TQ_SLOT( socketConnectionClosed() ) );
+		disconnect( socket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( socketReadyRead() ) );
+		disconnect( socket, TQ_SIGNAL( error( int ) ), this, TQ_SLOT( socketError( int ) ) );
+		disconnect( socket, TQ_SIGNAL( hostFound() ), this, TQ_SLOT( hostFound() ) );
 		
 		socket->clearPendingData();
 		socket->close();
 		if ( socket->state() == TQSocket::Closing )
 		{
 			// We have a delayed close.
-			connect( socket, TQT_SIGNAL( delayedCloseFinished() ), this, TQT_SLOT( socketClosed() ) );
+			connect( socket, TQ_SIGNAL( delayedCloseFinished() ), this, TQ_SLOT( socketClosed() ) );
 		}
 		else
 		{
@@ -86,10 +86,10 @@ void OpenvpnManagementHandler::socketConnectionClosed()
 void OpenvpnManagementHandler::socketClosed()
 {
 	socketReallyClosed = false;
-	disconnect( socket, TQT_SIGNAL( delayedCloseFinished() ), this, TQT_SLOT( socketClosed() ) );
+	disconnect( socket, TQ_SIGNAL( delayedCloseFinished() ), this, TQ_SLOT( socketClosed() ) );
 	delete socket;
 	greetingtimer.stop();
-	disconnect ( &greetingtimer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( greetingTimedOut() ) );
+	disconnect ( &greetingtimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( greetingTimedOut() ) );
 	if ( GlobalConfig->KvpncDebugLevel > 1 )
 		GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n( "Socket to the OpenVPN manage port (%1) closed." ).arg( TQString().setNum( GlobalConfig->OpenvpnManagementPort ) ), GlobalConfig->debug );
 	socketReallyClosed = true;
@@ -99,8 +99,8 @@ void OpenvpnManagementHandler::socketClosed()
 void OpenvpnManagementHandler::socketConnected()
 {
 
-	connect( socket, TQT_SIGNAL( connectionClosed() ), this, TQT_SLOT( socketConnectionClosed() ) );
-	connect( socket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( socketReadyRead() ) );
+	connect( socket, TQ_SIGNAL( connectionClosed() ), this, TQ_SLOT( socketConnectionClosed() ) );
+	connect( socket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( socketReadyRead() ) );
 
 // 	KMessageBox::error ( 0, TQString("bar"), TQString("foo") );
 	connectedToManagementPort=true;
@@ -122,7 +122,7 @@ void OpenvpnManagementHandler::socketError( int e )
 
 void OpenvpnManagementHandler::greetingTimedOut()
 {
-	disconnect ( &greetingtimer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( greetingTimedOut() ) );
+	disconnect ( &greetingtimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( greetingTimedOut() ) );
 	greetingtimer.stop();
 
 	GlobalConfig->appendLogEntry( "OpenvpnManagementHandler: " + i18n("Got no greeting within %1 seconds from management interface, retrying.").arg("3"), GlobalConfig->error );
@@ -194,7 +194,7 @@ void OpenvpnManagementHandler::socketReadyRead()
 				if ( line.find( "INFO:OpenVPN Management Interface", 0, FALSE ) > -1 )
 				{
 					gotGreeting=true;
-					disconnect ( &greetingtimer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( greetingTimedOut() ) );
+					disconnect ( &greetingtimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( greetingTimedOut() ) );
 					greetingtimer.stop ();
 	
 					if ( GlobalConfig->KvpncDebugLevel > 2 )
@@ -836,16 +836,16 @@ void OpenvpnManagementHandler::socketReadyRead()
 				{
 					if (socket)
 					{
-						disconnect( socket, TQT_SIGNAL( connected() ), this, TQT_SLOT( socketConnected() ) );
-						disconnect( socket, TQT_SIGNAL( connectionClosed() ), this, TQT_SLOT( socketConnectionClosed() ) );
-						disconnect( socket, TQT_SIGNAL( readyRead() ), this, TQT_SLOT( socketReadyRead() ) );
-						disconnect( socket, TQT_SIGNAL( error( int ) ), this, TQT_SLOT( socketError( int ) ) );
-						disconnect( socket, TQT_SIGNAL( hostFound() ), this, TQT_SLOT( hostFound() ) );
+						disconnect( socket, TQ_SIGNAL( connected() ), this, TQ_SLOT( socketConnected() ) );
+						disconnect( socket, TQ_SIGNAL( connectionClosed() ), this, TQ_SLOT( socketConnectionClosed() ) );
+						disconnect( socket, TQ_SIGNAL( readyRead() ), this, TQ_SLOT( socketReadyRead() ) );
+						disconnect( socket, TQ_SIGNAL( error( int ) ), this, TQ_SLOT( socketError( int ) ) );
+						disconnect( socket, TQ_SIGNAL( hostFound() ), this, TQ_SLOT( hostFound() ) );
 						socket->close();
 						if ( socket->state() == TQSocket::Closing )
 						{
 								// We have a delayed close.
-								connect( socket, TQT_SIGNAL(delayedCloseFinished()), this, TQT_SLOT(socketClosed()) );
+								connect( socket, TQ_SIGNAL(delayedCloseFinished()), this, TQ_SLOT(socketClosed()) );
 						}
 						else
 						{
@@ -879,9 +879,9 @@ bool OpenvpnManagementHandler::doConnect()
 	socket = new TQSocket( this );
 	if (socket)
 	{
-		connect( socket, TQT_SIGNAL( connected() ), this, TQT_SLOT( socketConnected() ) );
-		connect( socket, TQT_SIGNAL( hostFound() ), this, TQT_SLOT( hostFound() ) );
-		connect( socket, TQT_SIGNAL( error( int ) ), this, TQT_SLOT( socketError( int ) ) );
+		connect( socket, TQ_SIGNAL( connected() ), this, TQ_SLOT( socketConnected() ) );
+		connect( socket, TQ_SIGNAL( hostFound() ), this, TQ_SLOT( hostFound() ) );
+		connect( socket, TQ_SIGNAL( error( int ) ), this, TQ_SLOT( socketError( int ) ) );
 	
 
 		if ( socket->state() == TQSocket::Idle )
@@ -892,7 +892,7 @@ bool OpenvpnManagementHandler::doConnect()
 			}
 			socket->connectToHost( "127.0.0.1", GlobalConfig->OpenvpnManagementPort );
 			
-			connect ( &greetingtimer, TQT_SIGNAL ( timeout() ), this, TQT_SLOT ( greetingTimedOut() ) );
+			connect ( &greetingtimer, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( greetingTimedOut() ) );
 			greetingtimer.start ( 3 * 1000, TRUE );
 		
 			if ( GlobalConfig->KvpncDebugLevel > 2 )
